@@ -6,7 +6,7 @@ from django.views.static import serve
 
 from fastadmin.settings import ROOT_DIR
 
-from .api import action, add, change, configuration, delete, export, get, list, me, sign_in, sign_out
+from .api import action, add, change, change_password, configuration, delete, export, get, list, me, sign_in, sign_out
 from .views import index
 
 
@@ -20,6 +20,7 @@ def get_admin_urls():
             path("api/list/<str:model>", list),
             path("api/retrieve/<str:model>/<str:id>", get),
             path("api/add/<str:model>", add),
+            path("api/change-password/<str:id>", change_password),
             path("api/change/<str:model>/<str:id>", change),
             path("api/export/<str:model>", export),
             path("api/delete/<str:model>/<str:id>", delete),
