@@ -9,8 +9,14 @@ import jwt
 from asgiref.sync import sync_to_async
 
 from fastadmin.api.exceptions import AdminApiException
-from fastadmin.api.helpers import get_user_id_from_session_id, sanitize
-from fastadmin.api.schemas import ActionInputSchema, ExportInputSchema, SignInInputSchema
+from fastadmin.api.helpers import get_user_id_from_session_id, sanitize_filter_key, sanitize_filter_value
+from fastadmin.api.schemas import (
+    ActionInputSchema,
+    ChangePasswordInputSchema,
+    ExportFormat,
+    ExportInputSchema,
+    SignInInputSchema,
+)
 from fastadmin.models.base import InlineModelAdmin, ModelAdmin
 from fastadmin.models.helpers import (
     generate_models_schema,
@@ -82,8 +88,6 @@ class ApiService:
         if not admin_model:
             raise AdminApiException(404, detail=f"{model} model is not registered.")
 
-        filters = {k: sanitize(v) for k, v in filters.items() if k not in ("search", "sort_by", "offset", "limit")}
-
         # validations
         fields = admin_model.get_fields_for_serialize()
 
@@ -92,11 +96,19 @@ class ApiService:
                 if field not in fields:
                     raise AdminApiException(422, detail=f"Search by {field} is not allowed")
 
+        exclude_filter_fields = ("search", "sort_by", "offset", "limit")
         if filters:
-            for filter_condition in filters.keys():
-                field = filter_condition.split("__", 1)[0]
+            for k in filters.keys():
+                if k in exclude_filter_fields:
+                    continue
+                field = k.split("__", 1)[0]
                 if field not in fields:
-                    raise AdminApiException(422, detail=f"Filter by {filter_condition} is not allowed")
+                    raise AdminApiException(422, detail=f"Filter by {k} is not allowed")
+            filters = {
+                sanitize_filter_key(k, admin_model.get_model_fields_with_widget_types()): sanitize_filter_value(v)
+                for k, v in filters.items()
+                if k not in exclude_filter_fields
+            }
 
         if sort_by:
             if sort_by.strip("-") not in fields:
@@ -153,6 +165,33 @@ class ApiService:
             raise AdminApiException(404, detail=f"{model} model is not registered.")
         return await admin_model.save_model(None, payload)  # type: ignore
 
+    async def change_password(
+        self,
+        session_id: str | None,
+        id: UUID | int,
+        payload: dict,
+    ) -> None:
+        current_user_id = await get_user_id_from_session_id(session_id)
+        if not current_user_id:
+            raise AdminApiException(401, detail="User is not authenticated.")
+
+        admin_model = get_admin_model(settings.ADMIN_USER_MODEL)
+        if not admin_model:
+            raise AdminApiException(404, detail=f"{settings.ADMIN_USER_MODEL} model is not registered.")
+
+        payload = ChangePasswordInputSchema(**payload)
+
+        if not hasattr(admin_model, "change_password"):
+            raise AdminApiException(
+                404, detail=f"{settings.ADMIN_USER_MODEL} admin class has no change_password method."
+            )
+
+        if inspect.iscoroutinefunction(admin_model.change_password):
+            change_password_fn = admin_model.change_password
+        else:
+            change_password_fn = sync_to_async(admin_model.change_password)
+        await change_password_fn(id, payload.password)
+
     async def change(
         self,
         session_id: str | None,
@@ -181,7 +220,7 @@ class ApiService:
         search: str | None = None,
         sort_by: str | None = None,
         filters: dict = {},
-    ) -> tuple[str, StringIO | BytesIO | None]:
+    ) -> tuple[str, str, StringIO | BytesIO | None]:
         current_user_id = await get_user_id_from_session_id(session_id)
         if not current_user_id:
             raise AdminApiException(401, detail="User is not authenticated.")
@@ -190,15 +229,55 @@ class ApiService:
         if not admin_model:
             raise AdminApiException(404, detail=f"{model} model is not registered.")
 
-        filters = {k: sanitize(v) for k, v in filters.items() if k not in ("search", "sort_by", "offset", "limit")}
-        file_name = f"{model}.{(payload.format or 'csv').lower()}"
-        return file_name, await admin_model.get_export(
-            payload.format,
-            search=search,
-            sort_by=sort_by,
-            filters=filters,
-            offset=payload.offset,
-            limit=payload.limit,
+        # validations
+        fields = admin_model.get_fields_for_serialize()
+
+        if search and admin_model.search_fields:
+            for field in admin_model.search_fields:
+                if field not in fields:
+                    raise AdminApiException(422, detail=f"Search by {field} is not allowed")
+
+        exclude_filter_fields = ("search", "sort_by", "offset", "limit")
+        if filters:
+            for k in filters.keys():
+                if k in exclude_filter_fields:
+                    continue
+                field = k.split("__", 1)[0]
+                if field not in fields:
+                    raise AdminApiException(422, detail=f"Filter by {k} is not allowed")
+            filters = {
+                sanitize_filter_key(k, admin_model.get_model_fields_with_widget_types()): sanitize_filter_value(v)
+                for k, v in filters.items()
+                if k not in exclude_filter_fields
+            }
+
+        if sort_by:
+            if sort_by.strip("-") not in fields:
+                raise AdminApiException(422, detail=f"Sort by {sort_by} is not allowed")
+        elif admin_model.ordering:
+            for ordering_field in admin_model.ordering:
+                if ordering_field.strip("-") not in fields:
+                    raise AdminApiException(422, detail=f"Sort by {ordering_field} is not allowed")
+
+        content_type = "text/plain"
+        file_name = f"{model}.txt"
+        if payload.format == ExportFormat.CSV:
+            content_type = "text/csv"
+            file_name = f"{model}.csv"
+        elif payload.format == ExportFormat.JSON:
+            content_type = "text/plain"
+            file_name = f"{model}.json"
+        return (
+            file_name,
+            content_type,
+            await admin_model.get_export(
+                payload.format,
+                search=search,
+                sort_by=sort_by,
+                filters=filters,
+                offset=payload.offset,
+                limit=payload.limit,
+            ),
         )
 
     async def delete(
