@@ -22,12 +22,12 @@ class SqlAlchemyMixin:
     def get_model_fields_with_widget_types(
         self,
         with_m2m: bool | None = None,
+        with_upload: bool | None = None,
     ) -> list[ModelFieldWidgetSchema]:
         """This method is used to get model fields with widget types.
 
         :params with_m2m: a flag to include m2m fields.
-        :params with_pk: a flag to include pk fields.
-        :params with_readonly: a flag to include readonly fields.
+        :params with_upload: a flag to include upload fields.
         :return: A list of ModelFieldWidgetSchema.
         """
         mapper = inspect(self.model_cls)
@@ -54,11 +54,15 @@ class SqlAlchemyMixin:
                     continue
 
             is_m2m = field_type == "MANYTOMANY"
+            is_upload = False
             if with_m2m is not None and not with_m2m and is_m2m:
                 continue
-
             if with_m2m is not None and with_m2m and not is_m2m:
                 continue
+            if with_upload is not None and not with_upload and is_upload:
+                continue
+            if with_upload is not None and with_upload and not is_upload:
+                continue
 
             is_pk = self.get_model_pk_name(self.model_cls) == field_name
             is_immutable = (
@@ -362,6 +366,7 @@ class SqlAlchemyMixin:
 
         :params obj: an object.
         :params field: a m2m field name.
+        :params ids: a list of ids.
 
         :return: A list of ids.
         """
@@ -394,6 +399,17 @@ class SqlAlchemyMixin:
             await session.execute(orm_model_field.secondary.insert().values(values))
             await session.commit()
 
+    async def orm_save_upload_field(self, obj: Any, field: str, base64: str) -> None:
+        """This method is used to save upload field.
+
+        :params obj: an object.
+        :params field: a m2m field name.
+        :params base64: a base64 string.
+
+        :return: A list of ids.
+        """
+        pass
+
 
 class SqlAlchemyModelAdmin(SqlAlchemyMixin, ModelAdmin):
     pass
